@@ -90,6 +90,11 @@ def main():
         logger.warning("User not in Docker group, elevating...")
         elevate.elevate(graphical=False)
 
+    if args.update:
+        logger.info("Checking for Updates...")
+        subprocess.call(["python3", "-m", "pip", "install", "-U", "rete"])
+        return
+
     try:
         client = docker.from_env()
         # Verify docker is running
@@ -109,10 +114,6 @@ def main():
             cntr.stop()
         logger.info("Done.")
         return
-    elif args.update:
-        logger.info("Checking for Updates...")
-        subprocess.call(["python3", "-m", "pip", "install", "-U", "rete"])
-        return
 
     # Lets download the latest image
     pull_image(client, args.browser)
